Avenue: Highway routing.
=============================================

Release v\ |release| (:doc:`What's new? <changelog>`).


.. include:: ../README.rst
   :start-after: teaser-begin


User's Guide
------------

.. toctree::
   :maxdepth: 1

   examples
   api


Project Information
-------------------

.. toctree::
   :maxdepth: 1

   license
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
